import { validate } from 'superstruct';
import get from 'lodash/get';
import * as I18N from './i18n';
import { WebpackSourceStruct } from './schemas';
function extractFailedStructure(webpackSource, failurePath) {
    if (failurePath.length === 0) {
        return null;
    }
    const source = get(webpackSource, failurePath);
    if (typeof source === 'object') {
        return {
            path: failurePath.join('.'),
            source,
        };
    }
    return extractFailedStructure(webpackSource, failurePath.slice(0, -1));
}
export default (webpackSource) => {
    const res = validate(webpackSource, WebpackSourceStruct);
    if (!(res === null || res === void 0 ? void 0 : res[0])) {
        return '';
    }
    const failures = res[0].failures();
    const output = [`${I18N.INVALID}`];
    failures.forEach((failure) => {
        const failureOutput = ['', failure.message, `Path: ${failure.path.join('.')}`];
        const failedSource = extractFailedStructure(webpackSource, failure.path);
        if (failedSource) {
            failureOutput.push(`Failed structure(${failedSource.path}): ${JSON.stringify(failedSource.source, null, 2)}`);
        }
        output.push(failureOutput.join('\n'));
    });
    return output.join('\n');
};
//# sourceMappingURL=index.js.map