import isEmpty from 'lodash/isEmpty';
import { SOURCE_PATHS } from '../config';
import { getGlobalMetricType, getMetricRunInfo } from '../utils/metrics';
import * as webpack from '../webpack';
import { version } from '../../package.json';
export const createReport = (jobs) => {
    var _a;
    const insights = (_a = jobs[0]) === null || _a === void 0 ? void 0 : _a.insights;
    const summary = SOURCE_PATHS.reduce((agg, sourceId) => {
        var _a, _b;
        const sourceSummary = (_b = (_a = jobs[0]) === null || _a === void 0 ? void 0 : _a.summary) === null || _b === void 0 ? void 0 : _b[sourceId];
        if (!sourceSummary) {
            return agg;
        }
        const output = Object.entries(sourceSummary).map(([metricId, summaryData]) => {
            const metric = getGlobalMetricType(`${sourceId}.${metricId}`);
            const { current = 0, baseline = 0 } = summaryData;
            const info = getMetricRunInfo(metric, current, baseline);
            return {
                label: metric.label,
                ...info,
            };
        });
        return {
            ...agg,
            [sourceId]: output,
        };
    }, {});
    return {
        createdAt: new Date().toISOString(),
        version,
        runs: jobs.map(({ internalBuildNumber, meta }) => ({
            ...meta,
            internalBuildNumber,
        })),
        summary,
        ...(!isEmpty(insights) ? { insights } : {}),
        ...webpack.compare(jobs),
    };
};
//# sourceMappingURL=create.js.map