import get from 'lodash/get';
import map from 'lodash/map';
import orderBy from 'lodash/orderBy';
import sum from 'lodash/sum';
import { INSIGHT_WARNING } from '../../config';
export const extractModulesPackagesDuplicate = (webpackStats, currentExtractedData) => {
    const source = get(currentExtractedData, 'metrics.packages', {});
    const packagesByName = Object.entries(source).reduce((agg, [packageId, packageData]) => {
        const { name } = packageData;
        const existingPackageData = agg[name];
        return {
            ...agg,
            [name]: {
                ...existingPackageData,
                children: [
                    ...((existingPackageData === null || existingPackageData === void 0 ? void 0 : existingPackageData.children) || []),
                    {
                        name: packageId,
                        value: packageData.value,
                    },
                ],
            },
        };
    }, {});
    const { count, duplicatePackages } = Object.entries(packagesByName).reduce((agg, [name, data]) => {
        const duplicateInstances = data.children.length - 1;
        if (duplicateInstances === 0) {
            return agg;
        }
        return {
            count: agg.count + duplicateInstances,
            duplicatePackages: [
                ...(agg.duplicatePackages || []),
                {
                    name,
                    value: sum(map(data.children, 'value')),
                    ...data,
                },
            ],
        };
    }, { count: 0, duplicatePackages: [] });
    if (!count) {
        return {
            metrics: {
                duplicatePackagesCount: {
                    value: count,
                },
            },
        };
    }
    const duplicatePackagesByName = orderBy(duplicatePackages, 'value', 'desc').reduce((agg, { name, ...duplicatePackageData }) => ({
        ...agg,
        [name]: {
            ...duplicatePackageData,
            children: orderBy(duplicatePackageData.children, 'value', 'desc'),
        },
    }), {});
    const data = Object.entries(duplicatePackagesByName).reduce((agg, [packageName, duplicatePackageData]) => ({
        ...agg,
        [packageName]: duplicatePackageData.children.map(({ name }) => name),
    }), {});
    return {
        insights: {
            duplicatePackages: {
                type: INSIGHT_WARNING,
                data,
            },
        },
        metrics: {
            duplicatePackagesCount: {
                value: count,
            },
        },
    };
};
//# sourceMappingURL=modules-packages-duplicate.js.map