import round from 'lodash/round';
import { getModuleName, normalizeChunkId } from '../utils';
export const extractModules = (webpackStats) => {
    const modulesSource = webpackStats === null || webpackStats === void 0 ? void 0 : webpackStats.modules;
    if (!modulesSource) {
        return {
            metrics: {
                duplicateCode: { value: 0 },
                duplicateModulesCount: { value: 0 },
                modules: {},
                moduleCount: { value: 0 },
            },
        };
    }
    const allModules = modulesSource.reduce((agg, moduleEntry) => {
        if (!moduleEntry.modules) {
            agg.push(moduleEntry);
            return agg;
        }
        agg = agg.concat(moduleEntry.modules.map((concatenatedModule) => ({
            ...concatenatedModule,
            chunks: moduleEntry.chunks,
        })));
        return agg;
    }, []);
    let moduleCount = 0;
    let totalCodeSize = 0;
    let duplicateCodeSize = 0;
    let duplicateModulesCount = 0;
    const modules = allModules.reduce((agg, moduleEntry) => {
        const { name, size = 0, chunks } = moduleEntry;
        const normalizedName = getModuleName(name);
        if (!chunks || (chunks === null || chunks === void 0 ? void 0 : chunks.length) === 0) {
            return agg;
        }
        const instances = chunks.length;
        const duplicateInstances = instances - 1;
        moduleCount += instances;
        duplicateModulesCount += duplicateInstances;
        duplicateCodeSize += duplicateInstances * size;
        totalCodeSize += instances * size;
        agg[normalizedName] = {
            name,
            value: size,
            chunkIds: chunks.map(normalizeChunkId),
            duplicated: Boolean(duplicateInstances),
        };
        return agg;
    }, {});
    const duplicateCode = totalCodeSize ? round((duplicateCodeSize / totalCodeSize) * 100, 2) : 0;
    return {
        metrics: {
            modules,
            duplicateCode: {
                value: duplicateCode,
            },
            duplicateModulesCount: {
                value: duplicateModulesCount,
            },
            moduleCount: {
                value: moduleCount,
            },
        },
    };
};
//# sourceMappingURL=modules.js.map