"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeChunkId = exports.getPackagePublicName = exports.getMetricType = exports.getMetricDeleted = exports.getMetricAdded = exports.calculateCacheInvalidation = exports.getModuleName = exports.getAssetName = void 0;
const last_1 = __importDefault(require("lodash/last"));
const map_1 = __importDefault(require("lodash/map"));
const round_1 = __importDefault(require("lodash/round"));
const config_1 = require("../config");
const metrics_1 = require("../utils/metrics");
const metrics_2 = require("./metrics");
const HASH_PATTERN = '[a-f|0-9]{5,32}';
const HASH_SEPARATOR_PATTERN = '[-|.]';
const EXTENSION_PATTERN = /(?:\.[a-z|0-9]{2,}){1,}/;
const PATTERNS = [
    `(.*)${HASH_SEPARATOR_PATTERN}${HASH_PATTERN}(${EXTENSION_PATTERN.source})$`,
    `(static)/${HASH_PATTERN}(.*${EXTENSION_PATTERN.source})$`,
].map((pattern) => new RegExp(pattern));
const NO_BASENAME = /(^|.*\/)\..*$/;
const getAssetName = (assetFilepath) => {
    if (!assetFilepath) {
        return '';
    }
    let result;
    for (let i = 0; i < PATTERNS.length && !result; i += 1) {
        const pattern = PATTERNS[i];
        const extracted = assetFilepath.replace(pattern, '$1$2');
        if (extracted && extracted !== assetFilepath && !NO_BASENAME.test(extracted)) {
            result = extracted;
        }
    }
    if (!result) {
        return assetFilepath;
    }
    return result;
};
exports.getAssetName = getAssetName;
const NAME_WITH_LOADERS = /!/;
const NAME_WITH_MODULES = /\s\+\s\d*\smodules$/;
const INVALID_CSS_PREFIX = /^css\s.*node_modules(?!\/)/;
const getModuleName = (name) => {
    if (!name) {
        return '';
    }
    if (NAME_WITH_LOADERS.test(name)) {
        const normalizedName = (0, last_1.default)(name.split(NAME_WITH_LOADERS));
        if (normalizedName?.trim()) {
            return normalizedName;
        }
    }
    if (NAME_WITH_MODULES.test(name)) {
        return name.replace(NAME_WITH_MODULES, '');
    }
    if (INVALID_CSS_PREFIX.test(name)) {
        return name.replace(INVALID_CSS_PREFIX, '');
    }
    return name;
};
exports.getModuleName = getModuleName;
const calculateCacheInvalidation = (rows) => {
    let cached = 0;
    let invalidated = 0;
    rows.forEach(({ changed, added, deleted, runs }) => {
        if (added || deleted) {
            return;
        }
        if (changed) {
            invalidated += runs[1].value;
        }
        cached += runs[1].value;
    });
    if (cached === 0) {
        return 0;
    }
    return (0, round_1.default)((invalidated / cached) * 100, 2);
};
exports.calculateCacheInvalidation = calculateCacheInvalidation;
const getMetricAdded = (runs) => {
    const [current, baseline] = (0, map_1.default)(runs, 'value');
    return Boolean(current !== null && !baseline);
};
exports.getMetricAdded = getMetricAdded;
const getMetricDeleted = (runs) => {
    const [current, baseline] = (0, map_1.default)(runs, 'value');
    return Boolean(baseline !== null && !current);
};
exports.getMetricDeleted = getMetricDeleted;
exports.getMetricType = (0, metrics_1.createGetMetricType)(metrics_2.metrics);
const getPackagePublicName = (packageId) => {
    const name = (0, last_1.default)(packageId.split(config_1.PACKAGES_SEPARATOR));
    return name.split(config_1.PACKAGE_ID_SEPARATOR)[0];
};
exports.getPackagePublicName = getPackagePublicName;
const normalizeChunkId = (chunkId) => chunkId.toString();
exports.normalizeChunkId = normalizeChunkId;
//# sourceMappingURL=utils.js.map