import get from 'lodash/get';
import template from 'lodash/template';

import { INSIGHT_INFO } from '../../config/insights';
import { getMetricRunInfo } from '../../utils/metrics';
import { getMetricType } from '../utils';

const INFO_TEMPLATE = template(
  '<%= metric %> — <%= displayValue %> (<%= displayDeltaPercentage %>).',
);
const METRIC_NAME = 'totalSizeByTypeALL';

export const extractAssetsSizeTotalInsight = (
  webpackStats,
  currentExtractedData,
  baselineBundleStats,
) => {
  const currentValue = get(currentExtractedData, ['metrics', METRIC_NAME, 'value'], 0);
  const baselineValue = get(baselineBundleStats, ['metrics', 'webpack', METRIC_NAME, 'value'], 0);

  const metric = getMetricType(METRIC_NAME);
  const info = getMetricRunInfo(metric, currentValue, baselineValue);
  const { displayDeltaPercentage, displayValue } = info;

  return {
    insights: {
      assetsSizeTotal: {
        type: INSIGHT_INFO,
        data: {
          text: INFO_TEMPLATE({ metric: metric.label, displayValue, displayDeltaPercentage }),
          md: INFO_TEMPLATE({
            metric: `*${metric.label}*`,
            displayValue: `*${displayValue}*`,
            displayDeltaPercentage: `*${displayDeltaPercentage}*`,
          }),
          info,
        },
      },
    },
  };
};
